/*
 * アンチ電ぷち v1
 * 
 * この程度のソースに著作権もクソもないけど、一応ライセンスはNYSLということにしておきます
 * 誰かよりまともによりスタイリッシュにしてください
 */
package extensions;

import dareka.extensions.Extension2;
import dareka.extensions.ExtensionManager;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Timer;
import java.util.TimerTask;

/**
 * アンチ電ぷちメインクラス
 */
public class AntiDenpuchi implements Extension2 {

  /**
   * タイマー
   */
  private Timer timer;

  @Override
  public void registerExtensions(ExtensionManager mgr) {
    // 書き込むファイルのパス
    final String path = System.getProperty("antiDenpuchiFilePath");
    // アクセス頻度(分)
    String accessIntervalString = System.getProperty("antiDenpuchiAccessInterval");
    long acccessInterval;
    try {
      acccessInterval = Long.parseLong(accessIntervalString);
      if (acccessInterval < 1 || acccessInterval > Long.MAX_VALUE / (60 * 1000)) {
        acccessInterval = 5;
      }
    } catch (NumberFormatException nfe) {
      acccessInterval = 5;
    }

    TimerTask task = new TimerTask() {
      @Override
      public void run() {
        File file = new File(path);

        // ファイルがなければ作る
        // 作れなかったら後は知らない
        if (!file.exists()) {
          try {
            boolean result = file.createNewFile();
            if (!result) {
              timer.cancel();
              return;
            }
          } catch (IOException ex) {
            timer.cancel();
            return;
          }
        }

        if (file.canWrite()) {
          try (FileWriter fw = new FileWriter(file)) {
            // ファイルに毎回変わる適当な値を書き込む
            Calendar cal = Calendar.getInstance();
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss.SSS");
            fw.write(sdf.format(cal.getTime()));
          } catch (IOException ex) {
            // なにかしたかったらどうにかしてください
          }
        }
      }
    };

    // タイマーに登録し適宜実行する
    timer = new Timer();
    timer.schedule(task, 0, acccessInterval * 60 * 1000);

    mgr.registerEventListener(new AntiDenpuchiListener());
  }

  @Override
  public String getVersionString() {
    return "AntiDenpuchi v1";
  }

  private class AntiDenpuchiListener implements dareka.extensions.SystemEventListener {

    @Override
    public int onSystemEvent(int id, EventSource source) {
      if (id == SYSTEM_EXIT) {
        timer.cancel();
      }
      return RESULT_OK;
    }
  }
}
